==> speech-analytic-testing_0.11.0_database.tar.gz: database/mssql/procedures/SaveEvaluationResult.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE PROCEDURE [dbo].[SaveEvaluationResult] (
	@Instance Varchar(50) = NULL,
	@Id Varchar(250) = NULL,
	@IdCampaign Varchar(50) = NULL,
	@IdInteraction Varchar(250) = NULL,
	@IdAgent Varchar(50) = NULL,
	@IdEvaluationFormat Varchar(50) = NULL,
	@MinQualificationAcceptable numeric(5,2) = NULL,
	@IdGroup Varchar(50) = NULL,
	@IdSubGroup Varchar(50) = NULL,
	@IdAbility Varchar(50) = NULL,
	@Qualification numeric(5,2) = NULL,
	@IdEvaluator Varchar(50) = NULL,
	@EvaluationDate Datetime = NULL,
	@MaxAbilityScore numeric(5,2) = NULL,
	@IdEvaluationPlan Varchar(50) = NULL,
	@Comment Varchar(1000) = NULL,
	@NotApplies bit = NULL,
	@ScoreDescription varchar(100) = NULL,
	@CampaignDescription varchar(100) = NULL,
	@AgentDescription varchar(100) = NULL,
	@InteractionDateini [datetime] = NULL,
	@InteractionDatefin [datetime] = NULL,
	@InteractionAddress [varchar](200) = NULL,
	@InteractionType varchar(50) = NULL,
	@AbilityOrder numeric(4,0) = NULL,
	@CreatedDate Datetime = NULL,
	@CreatedByUserId Varchar(50) = NULL,
	@LastModifiedDate Datetime = NULL,
	@LastModifiedByUserId Varchar(50) = NULL,
	@Conditional varchar(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	DECLARE @IdAbilityEvaluationFormat Varchar(50) = NULL

	-- RECUPERAMOS EL IDABILITYEVALUATIONFORMAT
	SELECT @IdAbilityEvaluationFormat = ID
		FROM [AbilityEvaluationFormat] (NOLOCK)
		WHERE [Instance] = @Instance
			AND [IdEvaluationFormat] = @IdEvaluationFormat
			AND [IdGroup] = @IdGroup
			AND [IdSubGroup] = @IdSubGroup
			AND [IdAbility] = @IdAbility
			AND isNull([Conditional],'') = isNull(@Conditional,'')

	-- BUSCAMOS SI YA EXISTE UN REGISTRO EN LA BASE DE DATOS PARA LA EVALUACION
	DECLARE @SAVED_QUALIFICATION NUMERIC(5, 2) = NULL

	SELECT @SAVED_QUALIFICATION = ER.[Qualification]
		FROM [dbo].[EvaluationResult] ER (NOLOCK)
		WHERE ER.[Instance] = @Instance
			AND ER.[IdEvaluationPlan] = @IdEvaluationPlan
			AND ER.[IdEvaluationFormat] = @IdEvaluationFormat
			AND ER.[IdAbility] = @IdAbility
			AND ER.[IdAbilityEvaluationFormat] = @IdAbilityEvaluationFormat
			AND ER.[IdInteraction] = @IdInteraction
			AND ER.[IdAuditor] = @IdEvaluator

	-- 
	IF @SAVED_QUALIFICATION IS NULL 
	BEGIN
		-- INSERTAMOS EL NUEVO RESULT
		INSERT INTO [dbo].[EvaluationResult]
			   ([Instance]
			   ,[IdCampaign]
			   ,[IdInteraction]
			   ,[IdAgent]
			   ,[IdEvaluationFormat]
			   ,[MinQualificationAcceptable]
			   ,[IdGroup]
			   ,[IdSubGroup]
			   ,[IdAbility]
			   ,[Qualification]
			   ,[IdEvaluator]
			   ,[IdAuditor]
			   ,[EvaluationDate]
			   ,[MaxAbilityScore]
			   ,[IdEvaluationPlan]
			   ,[Comment]
			   ,[NotApplies]
			   ,[ScoreDescription]
				,[CampaignDescription]
				,[AgentDescription]
				,[InteractionDateini]
				,[InteractionDatefin]
				,[InteractionAddress]
				,[InteractionType]
				,[AbilityOrder]
			   ,[CreatedDate]
			   ,[CreatedByUserId]
			   ,[LastModifiedDate]
			   ,[LastModifiedByUserId]
			   ,[IdAbilityEvaluationFormat]
			   ,[Conditional]
			   ,[TimeStamp]
			   )
		 VALUES
			   (
			   @Instance,
			   @IdCampaign,
				@IdInteraction,
				@IdAgent,
				@IdEvaluationFormat,
				@MinQualificationAcceptable ,
				@IdGroup, @IdSubGroup, @IdAbility,
				@Qualification,
				@IdEvaluator,
				@IdEvaluator,
				@EvaluationDate,
				@MaxAbilityScore,
				@IdEvaluationPlan,
				@Comment,
				@NotApplies,
				@ScoreDescription,
				@CampaignDescription,
				@AgentDescription,
				@InteractionDateini,
				@InteractionDatefin,
				@InteractionAddress,
				@InteractionType,
				@AbilityOrder,
				@CreatedDate,@CreatedByUserId,@LastModifiedDate,@LastModifiedByUserId,
				@IdAbilityEvaluationFormat,
				@Conditional,
			   GETUTCDATE())

	END
	ELSE
	BEGIN

		PRINT CONCAT('SAVED: ', @SAVED_QUALIFICATION)
		PRINT CONCAT('INPUT: ', @Qualification)

		-- ACTUALIZAMOS LA CALIFICACION EN CASO SEA DIFERENTE
		IF @SAVED_QUALIFICATION <> @Qualification
		BEGIN
			
			UPDATE [dbo].[EvaluationResult] 
				SET [Qualification] = @Qualification,
					[ScoreDescription] = @ScoreDescription,
					[IdEvaluator] = @IdEvaluator,
					[LastModifiedByUserId] = @LastModifiedByUserId,
					[LastModifiedDate] = @LastModifiedDate,
					[TimeStamp] = GETUTCDATE()
				WHERE [Instance] = @Instance
					AND [IdEvaluationPlan] = @IdEvaluationPlan
					AND [IdEvaluationFormat] = @IdEvaluationFormat
					AND [IdAbility] = @IdAbility
					AND [IdAbilityEvaluationFormat] = @IdAbilityEvaluationFormat
					AND [IdInteraction] = @IdInteraction
					AND [IdAuditor] = @IdEvaluator

		END
	END

    SELECT 1 AS 'result'

    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_0.16.1_database.tar.gz: database/mssql/procedures/SaveEvaluationResult.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE PROCEDURE [dbo].[SaveEvaluationResult] (
	@Instance Varchar(50) = NULL,
	@Id Varchar(250) = NULL,
	@IdCampaign Varchar(50) = NULL,
	@IdInteraction Varchar(250) = NULL,
	@IdAgent Varchar(50) = NULL,
	@IdEvaluationFormat Varchar(50) = NULL,
	@MinQualificationAcceptable numeric(5,2) = NULL,
	@IdGroup Varchar(50) = NULL,
	@IdSubGroup Varchar(50) = NULL,
	@IdAbility Varchar(50) = NULL,
	@Qualification numeric(5,2) = NULL,
	@OwnScore NUMERIC(5,2) = NULL,
	@InheritedScore NUMERIC(5,2) = NULL,
	@IdEvaluator Varchar(50) = NULL,
	@EvaluationDate Datetime = NULL,
	@MaxAbilityScore numeric(5,2) = NULL,
	@AbilityInnerScore NUMERIC(5,2) = NULL,
	@IdEvaluationPlan Varchar(50) = NULL,
	@Comment Varchar(1000) = NULL,
	@NotApplies bit = NULL,
	@ScoreDescription varchar(100) = NULL,
	@CampaignDescription varchar(100) = NULL,
	@AgentDescription varchar(100) = NULL,
	@InteractionDateini [datetime] = NULL,
	@InteractionDatefin [datetime] = NULL,
	@InteractionAddress VARCHAR(200) = NULL,
	@InteractionType varchar(50) = NULL,
	@AbilityOrder numeric(4,0) = NULL,
	@CreatedDate Datetime = NULL,
	@CreatedByUserId Varchar(50) = NULL,
	@LastModifiedDate Datetime = NULL,
	@LastModifiedByUserId Varchar(50) = NULL,
	@Conditional varchar(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	DECLARE @IdAbilityEvaluationFormat Varchar(50) = NULL

	-- RECUPERAMOS EL IDABILITYEVALUATIONFORMAT
	SELECT @IdAbilityEvaluationFormat = ID
		FROM [AbilityEvaluationFormat] (NOLOCK)
		WHERE [Instance] = @Instance
			AND [IdEvaluationFormat] = @IdEvaluationFormat
			AND [IdGroup] = @IdGroup
			AND [IdSubGroup] = @IdSubGroup
			AND [IdAbility] = @IdAbility
			AND isNull([Conditional],'') = isNull(@Conditional,'')

	-- BUSCAMOS SI YA EXISTE UN REGISTRO EN LA BASE DE DATOS PARA LA EVALUACION
	DECLARE @SAVED_QUALIFICATION NUMERIC(5, 2) = NULL

	SELECT @SAVED_QUALIFICATION = ER.[Qualification]
		FROM [dbo].[EvaluationResult] ER (NOLOCK)
		WHERE ER.[Instance] = @Instance
			AND ER.[IdEvaluationPlan] = @IdEvaluationPlan
			AND ER.[IdEvaluationFormat] = @IdEvaluationFormat
			AND ER.[IdAbility] = @IdAbility
			AND ER.[IdAbilityEvaluationFormat] = @IdAbilityEvaluationFormat
			AND ER.[IdInteraction] = @IdInteraction
			AND ER.[IdAuditor] = @IdEvaluator

	-- 
	IF @SAVED_QUALIFICATION IS NULL 
	BEGIN
		-- INSERTAMOS EL NUEVO RESULT
		INSERT INTO [dbo].[EvaluationResult]
			   ([Instance]
			   ,[IdCampaign]
			   ,[IdInteraction]
			   ,[IdAgent]
			   ,[IdEvaluationFormat]
			   ,[MinQualificationAcceptable]
			   ,[IdGroup]
			   ,[IdSubGroup]
			   ,[IdAbility]
			   ,[Qualification]
			   ,[OwnScore]
			   ,[InheritedScore]
			   ,[IdEvaluator]
			   ,[IdAuditor]
			   ,[EvaluationDate]
			   ,[MaxAbilityScore]
			   ,[AbilityInnerScore]
			   ,[IdEvaluationPlan]
			   ,[Comment]
			   ,[NotApplies]
			   ,[ScoreDescription]
				,[CampaignDescription]
				,[AgentDescription]
				,[InteractionDateini]
				,[InteractionDatefin]
				,[InteractionAddress]
				,[InteractionType]
				,[AbilityOrder]
			   ,[CreatedDate]
			   ,[CreatedByUserId]
			   ,[LastModifiedDate]
			   ,[LastModifiedByUserId]
			   ,[IdAbilityEvaluationFormat]
			   ,[Conditional]
			   ,[TimeStamp]
			   )
		 VALUES
			   (
			   @Instance,
			   @IdCampaign,
				@IdInteraction,
				@IdAgent,
				@IdEvaluationFormat,
				@MinQualificationAcceptable ,
				@IdGroup, @IdSubGroup, @IdAbility,
				@Qualification,
				@OwnScore,
				@InheritedScore,
				@IdEvaluator,
				@IdEvaluator,
				@EvaluationDate,
				@MaxAbilityScore,
				@AbilityInnerScore,
				@IdEvaluationPlan,
				@Comment,
				@NotApplies,
				@ScoreDescription,
				@CampaignDescription,
				@AgentDescription,
				@InteractionDateini,
				@InteractionDatefin,
				@InteractionAddress,
				@InteractionType,
				@AbilityOrder,
				@CreatedDate,@CreatedByUserId,@LastModifiedDate,@LastModifiedByUserId,
				@IdAbilityEvaluationFormat,
				@Conditional,
			   GETUTCDATE())

	END
	ELSE
	BEGIN

		PRINT CONCAT('SAVED: ', @SAVED_QUALIFICATION)
		PRINT CONCAT('INPUT: ', @Qualification)

		-- ACTUALIZAMOS LA CALIFICACION EN CASO SEA DIFERENTE
		IF @SAVED_QUALIFICATION <> @Qualification
		BEGIN
			
			UPDATE [dbo].[EvaluationResult] 
				SET [Qualification] = @Qualification,
					[OwnScore] = @OwnScore,
					[InheritedScore] = @InheritedScore,
					[AbilityInnerScore] = @AbilityInnerScore,
					[ScoreDescription] = @ScoreDescription,
					[IdEvaluator] = @IdEvaluator,
					[LastModifiedByUserId] = @LastModifiedByUserId,
					[LastModifiedDate] = @LastModifiedDate,
					[TimeStamp] = GETUTCDATE()
				WHERE [Instance] = @Instance
					AND [IdEvaluationPlan] = @IdEvaluationPlan
					AND [IdEvaluationFormat] = @IdEvaluationFormat
					AND [IdAbility] = @IdAbility
					AND [IdAbilityEvaluationFormat] = @IdAbilityEvaluationFormat
					AND [IdInteraction] = @IdInteraction
					AND [IdAuditor] = @IdEvaluator

		END
	END

    SELECT 1 AS 'result'

    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
